CursorStyle

Enum CursorStyle 

pub enum CursorStyle {
Show 21 variants Arrow, IBeam, Crosshair, ClosedHand, OpenHand, PointingHand, ResizeLeft, ResizeRight, ResizeLeftRight, ResizeUp, ResizeDown, ResizeUpDown, ResizeUpLeftDownRight, ResizeUpRightDownLeft, ResizeColumn, ResizeRow, IBeamCursorForVerticalLayout, OperationNotAllowed, DragLink, DragCopy, ContextualMenu,
}
The style of the cursor (pointer)

Variants



Arrow

The default cursor



IBeam

A text input cursor corresponds to the CSS cursor value text



Crosshair

A crosshair cursor corresponds to the CSS cursor value crosshair



ClosedHand

A closed hand cursor corresponds to the CSS cursor value grabbing



OpenHand

An open hand cursor corresponds to the CSS cursor value grab



PointingHand

A pointing hand cursor corresponds to the CSS cursor value pointer



ResizeLeft

A resize left cursor corresponds to the CSS cursor value w-resize



ResizeRight

A resize right cursor corresponds to the CSS cursor value e-resize



ResizeLeftRight

A resize cursor to the left and right corresponds to the CSS cursor value ew-resize



ResizeUp

A resize up cursor corresponds to the CSS cursor value n-resize



ResizeDown

A resize down cursor corresponds to the CSS cursor value s-resize



ResizeUpDown

A resize cursor directing up and down corresponds to the CSS cursor value ns-resize



ResizeUpLeftDownRight

A resize cursor directing up-left and down-right corresponds to the CSS cursor value nesw-resize



ResizeUpRightDownLeft

A resize cursor directing up-right and down-left corresponds to the CSS cursor value nwse-resize



ResizeColumn

A cursor indicating that the item/column can be resized horizontally. corresponds to the CSS cursor value col-resize



ResizeRow

A cursor indicating that the item/row can be resized vertically. corresponds to the CSS cursor value row-resize



IBeamCursorForVerticalLayout

A text input cursor for vertical layout corresponds to the CSS cursor value vertical-text



OperationNotAllowed

A cursor indicating that the operation is not allowed corresponds to the CSS cursor value not-allowed

A cursor indicating that the operation will result in a link corresponds to the CSS cursor value alias



DragCopy

A cursor indicating that the operation will result in a copy corresponds to the CSS cursor value copy



ContextualMenu

A cursor indicating that the operation will result in a context menu corresponds to the CSS cursor value context-menu