pub fn retain_all(id: impl Into<ElementId>) -> RetainAllImageCacheProviderExpand description
Constructs a retain-all image cache that uses the element state associated with the given ID.
pub fn retain_all(id: impl Into<ElementId>) -> RetainAllImageCacheProviderConstructs a retain-all image cache that uses the element state associated with the given ID.