register_action

Macro register_action 

register_action!() { /* proc-macro */ }
This can be used to register an action with the GPUI runtime when you want to manually implement the Action trait. Typically you should use the Action derive macro or actions! macro instead.