pub struct AnyEntity { /* private fields */ }Expand description
A dynamically typed reference to a entity, which can be downcast into a Entity<T>.
Implementations
Sourceimpl AnyEntity
impl AnyEntity
Sourcepub fn entity_type(&self) -> TypeId
pub fn entity_type(&self) -> TypeId
Returns the TypeId associated with this entity.
Sourcepub fn downgrade(&self) -> AnyWeakEntity
pub fn downgrade(&self) -> AnyWeakEntity
Converts this entity handle into a weak variant, which does not prevent it from being released.