KeybindingKeystroke

Struct KeybindingKeystroke 

pub struct KeybindingKeystroke { /* private fields */ }
Represents a keystroke that can be used in keybindings and displayed to the user.

Implementations

Source

impl KeybindingKeystroke

pub fn new_with_mapper( inner: Keystroke, use_key_equivalents: bool, keyboard_mapper: &dyn PlatformKeyboardMapper, ) -> Self

Create a new keybinding keystroke from the given keystroke using the given keyboard mapper.

pub fn from_keystroke(keystroke: Keystroke) -> Self

Create a new keybinding keystroke from the given keystroke, without any platform-specific mapping.

pub fn inner(&self) -> &Keystroke

Returns the GPUI representation of the keystroke.

pub fn modifiers(&self) -> &Modifiers

Returns the modifiers.

Platform-specific behavior:

  • On macOS and Linux, this modifiers is the same as inner.modifiers, which is the GPUI representation of the keystroke.
  • On Windows, this modifiers is the display modifiers, for example, a ctrl-@ keystroke will have inner.modifiers as Modifiers::control() and display_modifiers as Modifiers::control_shift().
pub fn key(&self) -> &str

Returns the key.

Platform-specific behavior:

  • On macOS and Linux, this key is the same as inner.key, which is the GPUI representation of the keystroke.
  • On Windows, this key is the display key, for example, a ctrl-@ keystroke will have inner.key as @ and display_key as 2.
pub fn set_modifiers(&mut self, modifiers: Modifiers)

Sets the modifiers. On Windows this modifies both inner.modifiers and display_modifiers.

pub fn set_key(&mut self, key: String)

Sets the key. On Windows this modifies both inner.key and display_key.

pub fn unparse(&self) -> String

Produces a representation of this key that Parse can understand.

pub fn remove_key_char(&mut self)

Removes the key_char